import React, { Component } from 'react';
import { View, Animated } from 'react-native';
import PropTypes from 'prop-types';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';

import Touchable from './Touchable';
import Font from './Font';

export default class Accordion extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]),
    title: PropTypes.string,
    contentHeight: PropTypes.number,
    isOpen: PropTypes.bool,
    isBorderTopVisible: PropTypes.bool,
    isBorderBottomVisible: PropTypes.bool,
    borderColor: PropTypes.string,
    titleColor: PropTypes.string,
    iconColor: PropTypes.string
  };

  static defaultProps = {
    children: <View />,
    title: '',
    contentHeight: 200,
    isOpen: false,
    isBorderTopVisible: true,
    isBorderBottomVisible: true,
    borderColor: '#cfcfcf',
    titleColor: '#4d4d4d',
    iconColor: '#4d4d4d'
  };

  state = {
    isOpen: this.props.isOpen
  };

  animatedValue = this.props.isOpen ? new Animated.Value(1) : new Animated.Value(0);

  animatedRotateZ = this.animatedValue.interpolate({
    inputRange: [0, 1],
    outputRange: ['0deg', '180deg']
  });

  animatedHeight = this.animatedValue.interpolate({
    inputRange: [0, 1],
    outputRange: [0, this.props.contentHeight]
  });

  animatedPaddingVertical = this.animatedValue.interpolate({
    inputRange: [0, 1],
    outputRange: [0, 16]
  });

  onPressAccordion = () => {
    if (this.state.isOpen) {
      Animated.timing(this.animatedValue, {
        toValue: 0,
        duration: 300
      }).start();

      this.setState({
        isOpen: false
      });
    }
    else {
      Animated.timing(this.animatedValue, {
        toValue: 1,
        duration: 300
      }).start();

      this.setState({
        isOpen: true
      });
    }
  };

  render() {
    return (
      <View>
        <Touchable onPress={this.onPressAccordion} debounce={300}>
          <View style={{
              height: 60,
              flexDirection: 'row',
              borderBottomWidth: this.props.isBorderBottomVisible ? 1 : 0,
              borderBottomColor: this.props.borderColor,
              borderTopWidth: this.props.isBorderTopVisible ? 1 : 0,
              borderTopColor: this.props.borderColor
            }}
          >
            <View style={{ flex: 1, paddingLeft: 16, justifyContent: 'center' }}>
              <Font.H4 color={this.props.titleColor}>{ this.props.title }</Font.H4>
            </View>
            <Animated.View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center', transform: [{ rotateZ: this.animatedRotateZ }] }}>
              <SimpleLineIcons name="arrow-down" size={23} color={this.props.iconColor} />
            </Animated.View>
          </View>
        </Touchable>
        <Animated.View style={{ overflow: 'hidden', height: this.animatedHeight, paddingVertical: this.animatedPaddingVertical }}>
          { this.props.children }
        </Animated.View>
      </View>
    );
  }
}
