import React, { Component } from 'react';
import { Platform, View } from 'react-native';
import PropTypes from 'prop-types';
import { Calendar, LocaleConfig } from 'react-native-calendars';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';

export default class _Calendar extends Component {
  static propTypes = {
    fontFamily: PropTypes.string,
    keyColor: PropTypes.string,
    titleColor: PropTypes.string,
    todayTextColor: PropTypes.string,
    dayTextColor: PropTypes.string
  };

  static defaultProps = {
    fontFamily: Platform.OS == 'android' ? 'sans-serif' : 'Apple SD Gothic Neo',
    keyColor: '#4d4d4d',
    titleColor: '#4d4d4d',
    todayTextColor: '#4d4d4d',
    dayTextColor: '#4d4d4d'
  };

  componentWillMount() {
    LocaleConfig.locales['kr'] = {
      monthNames: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      monthNamesShort: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
      dayNames: ['일요일', '월요일', '화요일', '수요일', '목요일', '금요일', '토요일'],
      dayNamesShort: ['일', '월', '화', '수', '목', '금', '토']
    };

    LocaleConfig.defaultLocale = 'kr';
  }

  renderArrow = (direction) => {
    if (direction == 'left') {
      return (
        <SimpleLineIcons name="arrow-left" size={28} color={this.props.keyColor} />
      );
    }
    else if (direction == 'right') {
      return (
        <SimpleLineIcons name="arrow-right" size={28} color={this.props.keyColor} />
      );
    }
  };

  render() {
    return (
      <View style={{ flex: 1 }}>
        <Calendar
          {...this.props}
          monthFormat="yyyy년 M월"
          renderArrow={this.renderArrow}
          theme={{
            textSectionTitleColor: this.props.titleColor,
            selectedDayBackgroundColor: this.props.keyColor,
            todayTextColor: this.props.todayTextColor,
            dayTextColor: this.props.dayTextColor,
            dotColor: this.props.keyColor,
            monthTextColor: this.props.keyColor,
            textDayFontFamily: this.props.fontFamily,
            textMonthFontFamily: this.props.fontFamily,
            textDayHeaderFontFamily: this.props.fontFamily,
            textDayFontSize: 14,
            textMonthFontSize: 18,
            textDayHeaderFontSize: 14
          }}
          hideExtraDays
        />
        <View
          style={{
            width: 50,
            height: 1,
            backgroundColor: this.props.keyColor,
            position: 'absolute',
            top: 45,
            left: '50%',
            transform: [{ translateX: -25 }]
          }}
        />
      </View>
    );
  }
}
