import React, { Component } from 'react';
import { Text, Platform } from 'react-native';
import PropTypes from 'prop-types';

export default class H1 extends Component {
  static propTypes = {
    children: PropTypes.node.isRequired,
    marginTop: PropTypes.number,
    marginLeft: PropTypes.number,
    fontSize: PropTypes.number,
    color: PropTypes.string,
    textAlign: PropTypes.string,
    onPress: PropTypes.func,
    fontWeight: PropTypes.string,
    isFontScalingAllowed: PropTypes.bool,
    fontFamily: PropTypes.string,
    style: PropTypes.object,
    debounce: PropTypes.number,
    name: PropTypes.string,
    lineHeight: PropTypes.number,
    numberOfLines: PropTypes.number
  };

  static defaultProps = {
    marginTop: 0,
    marginLeft: 0,
    fontSize: 19,
    color: '#4d4d4d',
    textAlign: 'left',
    onPress: null,
    fontWeight: 'normal',
    isFontScalingAllowed: false,
    fontFamily: Platform.OS == 'android' ? 'sans-serif' : 'Apple SD Gothic Neo',
    style: {},
    debounce: 1000,
    name: '',
    lineHeight: null,
    numberOfLines: null
  };

  isTextPressed = false;

  onPressText = () => {
    if (this.isTextPressed) {
      return;
    }

    this.isTextPressed = true;

    setTimeout(() => {
      this.isTextPressed = false;
    }, this.props.debounce);

    this.props.onPress(this.props.name);
  };

  render() {
    let onPressText = null;

    if (this.props.onPress) {
      onPressText = this.onPressText;
    }
    else {
      onPressText = null;
    }

    return (
      <Text
        onPress={onPressText}
        style={[
          {
            marginLeft: this.props.marginLeft,
            backgroundColor: 'transparent',
            fontSize: this.props.fontSize,
            color: this.props.color,
            marginTop: this.props.marginTop,
            textAlign: this.props.textAlign,
            fontWeight: this.props.fontWeight,
            fontFamily: this.props.fontFamily,
            lineHeight: this.props.lineHeight
          },
          this.props.style
        ]}
        allowFontScaling={this.props.isFontScalingAllowed}
        numberOfLines={this.props.numberOfLines}
      >
        { this.props.children }
      </Text>
    );
  }
}
