import React, { Component } from 'react';
import { View, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import Ionicons from 'react-native-vector-icons/Ionicons';

import Font from './Font';

export default class Header extends Component {
  static propTypes = {
    title: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    titleColor: PropTypes.string,
    titleFontSize: PropTypes.number,
    onPressTitle: PropTypes.func,
    backgroundColor: PropTypes.string,
    leftIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    onPressLeftIcon: PropTypes.func,
    rightIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    onPressRightIcon: PropTypes.func,
    height: PropTypes.number,
    debounce: PropTypes.number
  };

  static defaultProps = {
    title: '',
    titleColor: '#4d4d4d',
    titleFontSize: 18,
    onPressTitle: () => {},
    backgroundColor: '#ffffff',
    leftIcon: <Ionicons name="ios-arrow-round-back" color="#4d4d4d" size={52} />,
    onPressLeftIcon: () => {},
    rightIcon: <View />,
    onPressRightIcon: () => {},
    height: 60,
    debounce: 1000
  };

  isPressed = false;

  onPressTitle = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressTitle();
  };

  onPressLeftIcon = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressLeftIcon();
  };

  onPressRightIcon = () => {
    if (this.isPressed) {
      return;
    }

    this.isPressed = true;

    setTimeout(() => {
      this.isPressed = false;
    }, this.props.debounce);

    this.props.onPressRightIcon();
  };

  render() {
    return (
      <View style={{ flexDirection: 'row', backgroundColor: this.props.backgroundColor, height: this.props.height }}>
        <View style={{ flex: 1 }}>
          { this.props.leftIcon &&
            <TouchableWithoutFeedback onPress={this.onPressLeftIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.leftIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
        { typeof this.props.title == 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                <Font.H2 color={this.props.titleColor} fontSize={this.props.titleFontSize}>{ this.props.title }</Font.H2>
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        { typeof this.props.title != 'string' &&
          <View style={{ flex: 4 }}>
            <TouchableWithoutFeedback onPress={this.onPressTitle}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.title }
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        <View style={{ flex: 1 }}>
          { this.props.rightIcon &&
            <TouchableWithoutFeedback onPress={this.onPressRightIcon}>
              <View style={{ flex: 1, alignItems: 'center', justifyContent: 'center' }}>
                { this.props.rightIcon }
              </View>
            </TouchableWithoutFeedback>
          }
        </View>
      </View>
    );
  }
}
