import React, { Component } from 'react';
import { View } from 'react-native';
import PropTypes from 'prop-types';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';

import Touchable from '../components/Touchable';
import Font from './Font';

export default class ListItem extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element,
      PropTypes.array
    ]),
    onPress: PropTypes.func,
    leftIcon: PropTypes.element,
    rightIcon: PropTypes.element,
    isBorderTopVisible: PropTypes.bool,
    isBorderBottomVisible: PropTypes.bool,
    borderColor: PropTypes.string,
    marginTop: PropTypes.number,
    backgroundColor: PropTypes.string,
    isDisabled: PropTypes.bool,
    height: PropTypes.number,
    name: PropTypes.string,
    textColor: PropTypes.string,
    textFontSize: PropTypes.number,
    debounce: PropTypes.number
  };

  static defaultProps = {
    children: '',
    onPress: () => {},
    leftIcon: null,
    rightIcon: <SimpleLineIcons name="arrow-right" size={23} color="#4d4d4d" />,
    isBorderTopVisible: true,
    isBorderBottomVisible: true,
    borderColor: '#cfcfcf',
    marginTop: 0,
    backgroundColor: 'transparent',
    isDisabled: false,
    height: 60,
    name: '',
    textColor: '#4d4d4d',
    textFontSize: 14,
    debounce: 1000
  };

  onPressListItem = () => {
    this.props.onPress(this.props.name);
  };

  render() {
    return (
      <Touchable onPress={this.onPressListItem} isDisabled={this.props.isDisabled} debounce={this.props.debounce}>
        <View
          style={{
            backgroundColor: this.props.backgroundColor,
            marginTop: this.props.marginTop,
            height: this.props.height,
            borderTopWidth: this.props.isBorderTopVisible ? 1 : 0,
            borderTopColor: this.props.borderColor,
            borderBottomWidth: this.props.isBorderBottomVisible ? 1 : 0,
            borderBottomColor: this.props.borderColor,
            flexDirection: 'row',
            paddingLeft: this.props.leftIcon ? 0 : 16
          }}
        >
          { this.props.leftIcon &&
            <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
              { this.props.leftIcon }
            </View>
          }
          <View style={{ flex: 1, justifyContent: 'center' }}>
            { typeof this.props.children == 'string' &&
              <Font.H4 color={this.props.textColor} fontSize={this.props.textFontSize}>{ this.props.children }</Font.H4>
            }
            { typeof this.props.children != 'string' &&
              this.props.children
            }
          </View>
          <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
            { this.props.rightIcon }
          </View>
        </View>
      </Touchable>
    );
  }
}
