import React, { Component } from 'react';
import { Keyboard, Animated, Platform, View } from 'react-native';
import PropTypes from 'prop-types';

export default class MagnetView extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]),
    style: PropTypes.object,
    offsetOnIos: PropTypes.number,
    offsetOnAndroid: PropTypes.number,
    isWorkingOnIos: PropTypes.bool,
    isWorkingOnAndroid: PropTypes.bool
  };

  static defaultProps = {
    children: <View />,
    style: {},
    offsetOnIos: 0,
    offsetOnAndroid: 0,
    isWorkingOnIos: true,
    isWorkingOnAndroid: false
  };

  animatedTranlateY = new Animated.Value(0);

  componentWillMount() {
    this.keyboardDidShowListener = Keyboard.addListener('keyboardDidShow', this.keyboardDidShow);
    this.keyboardDidHideListener = Keyboard.addListener('keyboardDidHide', this.keyboardDidHide);
  }

  componentWillUnmount() {
    this.keyboardDidShowListener.remove();
    this.keyboardDidHideListener.remove();
  }

  keyboardDidShow = (event) => {
    if (Platform.OS == 'ios' && this.props.isWorkingOnIos == false) {
      return;
    }

    if (Platform.OS == 'android' && this.props.isWorkingOnAndroid == false) {
      return;
    }

    let toValue = -event.endCoordinates.height;

    if (Platform.OS == 'ios') {
      toValue += this.props.offsetOnIos;
    }
    else if (Platform.OS == 'android') {
      toValue += this.props.offsetOnAndroid;
    }

    Animated.timing(this.animatedTranlateY, {
      toValue: toValue,
      duration: 200
    }).start();
  };

  keyboardDidHide = () => {
    if (Platform.OS == 'ios' && this.props.isWorkingOnIos == false) {
      return;
    }

    if (Platform.OS == 'android' && this.props.isWorkingOnAndroid == false) {
      return;
    }

    Animated.timing(this.animatedTranlateY, {
      toValue: 0,
      duration: 200
    }).start();
  };

  render() {
    return (
      <Animated.View {...this.props} style={[{ transform: [{ translateY: this.animatedTranlateY }] }, this.props.style]}>
        { this.props.children }
      </Animated.View>
    );
  }
}
