import React, { Component } from 'react';
import { Animated, View } from 'react-native';
import PropTypes from 'prop-types';

export default class ParallaxItem extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]),
    parallaxScreenHeight: PropTypes.number.isRequired,
    height: PropTypes.number.isRequired,
    top: PropTypes.number.isRequired,
    left: PropTypes.number,
    interval: PropTypes.number,
    speed: PropTypes.number,
    animatedScrollY: PropTypes.instanceOf(Animated.Value).isRequired
  };

  static defaultProps = {
    children: <View />,
    left: 0,
    interval: 1,
    speed: 0.2
  };

  animatedTranslateY = Animated.modulo(Animated.add(Animated.multiply(this.props.animatedScrollY, -1 * this.props.speed), -(this.props.parallaxScreenHeight - this.props.top)), -(this.props.parallaxScreenHeight + this.props.height) * this.props.interval * (2 - this.props.speed));

  render() {
    return (
      <Animated.View
        style={{
          position: 'absolute',
          top: this.props.parallaxScreenHeight,
          left: this.props.left,
          transform: [{ translateY: this.animatedTranslateY }]
        }}
      >
        { this.props.children }
      </Animated.View>
    );
  }
}
