import React, { Component } from 'react';
import { View, Picker, Platform, Modal, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';

import Button from '../components/Button';
import Font from './Font';

export default class Select extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    label: PropTypes.string,
    value: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.number
    ]),
    onChange: PropTypes.func,
    labelColor: PropTypes.string,
    marginTop: PropTypes.number,
    buttonColor: PropTypes.string,
    buttonTextColor: PropTypes.string,
    name: PropTypes.string
  };

  static defaultProps = {
    label: '',
    value: '',
    onChange: () => {},
    labelColor: '#4d4d4d',
    marginTop: 0,
    buttonColor: '#4d4d4d',
    buttonTextColor: '#ffffff',
    name: ''
  };

  state = {
    isModalVisible: false,
    value: this.props.value.toString()
  };

  componentWillReceiveProps(nextProps) {
    this.setState({
      value: nextProps.value.toString()
    });
  }

  onPressLabel = () => {
    this.setState({
      isModalVisible: true
    });
  };

  onPressSelect = () => {
    this.props.onChange(this.state.value, this.props.name);

    this.setState({
      isModalVisible: false
    });
  };

  onPressCancel = () => {
    this.setState({
      isModalVisible: false,
      value: this.props.value
    });
  };

  onChangeSelect = (value) => {
    if (Platform.OS == 'android') {
      this.props.onChange(value, this.props.name);
    }
    else if (Platform.OS == 'ios') {
      this.setState({
        value: value
      });
    }
  };

  render() {
    if (Platform.OS == 'android') {
      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Font.H4 color={this.props.labelColor}>{ this.props.label }</Font.H4>
          </View>
          <View style={{ flex: 2, justifyContent: 'center' }}>
            <Picker
              selectedValue={this.props.value.toString()}
              onValueChange={this.onChangeSelect}
            >
              { this.props.children }
            </Picker>
          </View>
        </View>
      );
    }
    else if (Platform.OS == 'ios') {
      let picker = this.props.children.find((child) => {
        return child.props.value == this.props.value;
      });

      let label = null;

      if (picker) {
        label = picker.props.label;
      }
      else {
        label = this.props.children[0].props.value;
      }

      return (
        <View style={{ marginTop: this.props.marginTop, height: 60, flexDirection: 'row' }}>
          <Modal
            animationType="fade"
            transparent
            visible={this.state.isModalVisible}
          >
            <View style={{ flex: 1, justifyContent: 'center', backgroundColor: 'rgba(0, 0, 0, 0.5)' }}>
              <View style={{ height: 300, paddingHorizontal: 30 }}>
                <View style={{ backgroundColor: '#ffffff', borderRadius: 5 }}>
                  <View style={{ paddingHorizontal: 30 }}>
                    <Picker
                      selectedValue={this.state.value}
                      onValueChange={this.onChangeSelect}
                    >
                      { this.props.children }
                    </Picker>
                  </View>
                  <View style={{ position: 'absolute', width: 150, height: 60, justifyContent: 'center' }}>
                    <Font.H4 marginLeft={30}>{ this.props.label }</Font.H4>
                  </View>
                  <TouchableWithoutFeedback onPress={this.onPressCancel}>
                    <View style={{ position: 'absolute', right: 0, width: 60, height: 60, justifyContent: 'center', alignItems: 'flex-end', paddingRight: 30 }}>
                      <Font.H4 color="#007aff">취소</Font.H4>
                    </View>
                  </TouchableWithoutFeedback>
                  <View style={{ paddingHorizontal: 50 }}>
                    <Button buttonColor={this.props.buttonColor} textColor={this.props.buttonTextColor} onPress={this.onPressSelect}>선택</Button>
                  </View>
                  <View style={{ height: 20 }} />
                </View>
              </View>
            </View>
          </Modal>
          <View style={{ flex: 1, justifyContent: 'center' }}>
            <Font.H4 color={this.props.labelColor}>{ this.props.label }</Font.H4>
          </View>
          <TouchableWithoutFeedback onPress={this.onPressLabel}>
            <View style={{ flex: 2, flexDirection: 'row' }}>
              <View style={{ flex: 1, justifyContent: 'center' }}>
                <Font.H4>{ label }</Font.H4>
              </View>
              <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
                <SimpleLineIcons name="arrow-down" size={23} color="#4d4d4d" />
              </View>
            </View>
          </TouchableWithoutFeedback>
        </View>
      );
    }
  }
}
