import React, { Component } from 'react';
import { View, ScrollView, Dimensions, Animated } from 'react-native';
import PropTypes from 'prop-types';

export default class Swiper extends Component {
  static propTypes = {
    children: PropTypes.array.isRequired,
    bulletsColor: PropTypes.string,
    bulletsPosition: PropTypes.oneOf([
      'top',
      'bottom'
    ]),
    areBulletsVisible: PropTypes.bool,
    width: PropTypes.number,
    marginTop: PropTypes.number,
    defaultIndex: PropTypes.number,
    onSwipe: PropTypes.func
  };

  static defaultProps = {
    bulletsColor: '#ffffff',
    bulletsPosition: 'top',
    areBulletsVisible: true,
    width: Dimensions.get('window').width,
    marginTop: 0,
    defaultIndex: 0,
    onSwipe: () => {}
  };

  componentDidMount() {
    const x = this.props.defaultIndex * this.props.width;

    this.scrollViewRef.scrollTo({
      x: x
    });
  }

  animatedScrollX = new Animated.Value(0);

  animatedValue = this.animatedScrollX.interpolate({
    inputRange: [0, this.props.width * (this.props.children.length - 1)],
    outputRange: [0, this.props.children.length - 1]
  });

  animatedBulletTranslateX = this.animatedValue.interpolate({
    inputRange: [0, this.props.children.length - 1],
    outputRange: [0 - (5 + 5 + 10) * (this.props.children.length / 2 - 0.5), (5 + 5 + 10) * (this.props.children.length / 2 - 0.5)]
  });

  renderBullets = () => {
    return this.props.children.map((child, index) => {
      return (
        <View
          key={index}
          style={{
            width: 10,
            height: 10,
            borderRadius: 5,
            borderColor: this.props.bulletsColor,
            borderWidth: 1,
            marginLeft: 5,
            marginRight: 5
          }}
        />
      );
    });
  };

  onScrollEndDrag = () => {
    setTimeout(() => {
      const index = parseInt(this.animatedValue.__getValue());

      this.props.onSwipe(index);
    }, 500);
  };

  render() {
    const bottom = this.props.bulletsPosition == 'top' ? null : 0;

    return (
      <View style={{ alignItems: 'center', marginTop: this.props.marginTop, width: this.props.width }}>
        <ScrollView
          showsHorizontalScrollIndicator={false}
          horizontal
          pagingEnabled
          onScroll={Animated.event([{ nativeEvent: { contentOffset: { x: this.animatedScrollX } } }])}
          scrollEventThrottle={1}
          style={{ width: this.props.width }}
          ref={(ref) => { this.scrollViewRef = ref; }}
          onScrollEndDrag={this.onScrollEndDrag}
        >
          { this.props.children }
        </ScrollView>
        { this.props.areBulletsVisible &&
          <View
            style={{
              height: 60,
              position: 'absolute',
              flexDirection: 'row',
              alignItems: 'center',
              justifyContent: 'center',
              bottom: bottom
            }}
          >
            <Animated.View
              style={{
                transform: [{ translateX: this.animatedBulletTranslateX }],
                width: 10,
                height: 10,
                borderRadius: 5,
                backgroundColor: this.props.bulletsColor,
                position: 'absolute'
              }}
            />
            { this.renderBullets() }
          </View>
        }
      </View>
    );
  }
}
