import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Button from './Button';

export default class Toggle extends Component {
  static propTypes = {
    children: PropTypes.string,
    isChecked: PropTypes.bool,
    onChange: PropTypes.func,
    uncheckedButtonColor: PropTypes.string,
    checkedButtonColor: PropTypes.string,
    uncheckedTextColor: PropTypes.string,
    checkedTextColor: PropTypes.string,
    textFontSize: PropTypes.number,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    uncheckedBorderColor: PropTypes.string,
    checkedBorderColor: PropTypes.string,
    buttonStyle: PropTypes.object,
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    marginTop: PropTypes.number,
    marginLeft: PropTypes.number,
    name: PropTypes.string,
    height: PropTypes.number,
    width: PropTypes.number,
    paddingHorizontal: PropTypes.number,
    debounce: PropTypes.number
  };

  static defaultProps = {
    children: '',
    isChecked: false,
    onChange: () => {},
    uncheckedButtonColor: '#cfcfcf',
    checkedButtonColor: '#4d4d4d',
    uncheckedTextColor: '#ffffff',
    checkedTextColor: '#ffffff',
    textFontSize: 16,
    borderRadius: 3,
    borderWidth: 0,
    uncheckedBorderColor: '#cfcfcf',
    checkedBorderColor: '#4d4d4d',
    buttonStyle: {},
    textStyle: {},
    marginTop: 0,
    marginLeft: 0,
    name: '',
    height: 40,
    width: null,
    paddingHorizontal: 15,
    debounce: 0
  };

  onPressButton = (name) => {
    this.props.onChange(!this.props.isChecked, name);
  };

  render() {
    return (
      <Button
        onPress={this.onPressButton}
        buttonColor={this.props.isChecked ? this.props.checkedButtonColor : this.props.uncheckedButtonColor}
        buttonStyle={this.props.buttonStyle}
        height={this.props.height}
        width={this.props.width}
        textColor={this.props.isChecked ? this.props.checkedTextColor : this.props.uncheckedTextColor}
        borderRadius={this.props.borderRadius}
        textStyle={this.props.textStyle}
        marginTop={this.props.marginTop}
        marginLeft={this.props.marginLeft}
        textFontSize={this.props.textFontSize}
        borderWidth={this.props.borderWidth}
        borderColor={this.props.isChecked ? this.props.checkedBorderColor : this.props.uncheckedBorderColor}
        paddingHorizontal={this.props.paddingHorizontal}
        name={this.props.name}
        debounce={this.props.debounce}
      >
        { this.props.children }
      </Button>
    );
  }
}
