import React, { Component } from 'react';
import { View } from 'react-native';
import PropTypes from 'prop-types';
import _ from 'lodash';

import Toggle from './Toggle';

export default class Toggles extends Component {
  constructor(props) {
    super(props);

    this.state = this.getState(props);
  }

  static propTypes = {
    values: PropTypes.object,
    checkedValues: PropTypes.array, // eslint-disable-line
    checkedLabels: PropTypes.array, // eslint-disable-line
    marginTop: PropTypes.number,
    onChange: PropTypes.func,
    isEqualWidth: PropTypes.bool,
    max: PropTypes.number,
    uncheckedButtonColor: PropTypes.string,
    checkedButtonColor: PropTypes.string,
    uncheckedTextColor: PropTypes.string,
    checkedTextColor: PropTypes.string,
    textFontSize: PropTypes.number,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    uncheckedBorderColor: PropTypes.string,
    checkedBorderColor: PropTypes.string,
    buttonStyle: PropTypes.object,
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    name: PropTypes.string,
    width: PropTypes.number,
    height: PropTypes.number,
    paddingHorizontal: PropTypes.number,
    debounce: PropTypes.number,
    division: PropTypes.number
  };

  static defaultProps = {
    values: {},
    checkedValues: [],
    checkedLabels: [],
    marginTop: 0,
    onChange: () => {},
    isEqualWidth: true,
    max: 0,
    uncheckedButtonColor: '#cfcfcf',
    checkedButtonColor: '#4d4d4d',
    uncheckedTextColor: '#ffffff',
    checkedTextColor: '#ffffff',
    textFontSize: 16,
    borderRadius: 3,
    borderWidth: 0,
    uncheckedBorderColor: '#cfcfcf',
    checkedBorderColor: '#4d4d4d',
    buttonStyle: {},
    textStyle: {},
    name: '',
    width: null,
    height: 45,
    paddingHorizontal: 15,
    debounce: 0,
    division: 3
  };

  componentWillReceiveProps(nextProps) {
    this.setState(this.getState(nextProps));
  }

  getState = (props) => {
    const state = {};

    if (props.checkedLabels.length > 0) {
      _.forEach(props.values, (label, value) => {
        if (_.find(props.checkedLabels, (checkedLabel) => {
            return checkedLabel == label;
          })) {
          _.extend(state, {
            [`is${value}Checked`]: true
          });
        }
        else {
          _.extend(state, {
            [`is${value}Checked`]: false
          });
        }
      });
    }
    else {
      _.forEach(props.values, (label, value) => {
        if (_.find(props.checkedValues, (checkedValue) => {
            return checkedValue == value;
          })) {
          _.extend(state, {
            [`is${value}Checked`]: true
          });
        }
        else {
          _.extend(state, {
            [`is${value}Checked`]: false
          });
        }
      });
    }

    return state;
  };

  onChangeToggle = (isChecked, label, value) => {
    const checkedCount = _.reduce(this.state, (sum, isChecked) => {
      if (isChecked) {
        return sum + 1;
      }
      else {
        return sum;
      }
    }, 0);

    if (checkedCount >= this.props.max && this.props.max > 0 && isChecked) {
      return;
    }

    const state = _.cloneDeep(this.state);

    state[`is${value}Checked`] = isChecked;

    const checkedLabels = _.reduce(this.props.values, (checkedLabels, label, value) => {
      if (state[`is${value}Checked`]) {
        checkedLabels.push(label);
      }

      return checkedLabels;
    }, []);

    const checkedValues = _.reduce(this.props.values, (checkedValues, label, value) => {
      if (state[`is${value}Checked`]) {
        checkedValues.push(value);
      }

      return checkedValues;
    }, []);

    this.setState({
      [`is${value}Checked`]: isChecked
    });

    this.props.onChange(checkedLabels, checkedValues, this.props.name);
  };

  renderToggles = () => {
    let index = -1;

    const margin = 10 * (1 / this.props.division + 1);

    const width = 99 - margin;

    const marginLeft = margin / (this.props.division - 1);

    return _.map(this.props.values, (label, value) => {
      index++;

      if (this.props.isEqualWidth) {
        return (
          <View style={{ width: `${width / this.props.division}%`, marginLeft: index % this.props.division == 0 ? 0 : `${marginLeft}%`, marginTop: index < this.props.division ? 0 : 10 }} key={value}>
            <Toggle
              onChange={(isChecked) => { this.onChangeToggle(isChecked, label, value); }}
              isChecked={this.state[`is${value}Checked`]}
              uncheckedButtonColor={this.props.uncheckedButtonColor}
              checkedButtonColor={this.props.checkedButtonColor}
              uncheckedTextColor={this.props.uncheckedTextColor}
              checkedTextColor={this.props.checkedTextColor}
              borderRadius={this.props.borderRadius}
              buttonStyle={this.props.buttonStyle}
              textStyle={this.props.textStyle}
              textFontSize={this.props.textFontSize}
              borderWidth={this.props.borderWidth}
              uncheckedBorderColor={this.props.uncheckedBorderColor}
              checkedBorderColor={this.props.checkedBorderColor}
              width={this.props.width}
              height={this.props.height}
              paddingHorizontal={this.props.paddingHorizontal}
              debounce={this.props.debounce}
            >
              { label }
            </Toggle>
          </View>
        );
      }
      else {
        return (
          <View style={{ marginLeft: 10, marginTop: 10 }} key={value}>
            <Toggle
              onChange={(isChecked) => { this.onChangeToggle(isChecked, label, value); }}
              isChecked={this.state[`is${value}Checked`]}
              uncheckedButtonColor={this.props.uncheckedButtonColor}
              checkedButtonColor={this.props.checkedButtonColor}
              uncheckedTextColor={this.props.uncheckedTextColor}
              checkedTextColor={this.props.checkedTextColor}
              borderRadius={this.props.borderRadius}
              buttonStyle={this.props.buttonStyle}
              textStyle={this.props.textStyle}
              textFontSize={this.props.textFontSize}
              borderWidth={this.props.borderWidth}
              uncheckedBorderColor={this.props.uncheckedBorderColor}
              checkedBorderColor={this.props.checkedBorderColor}
              width={this.props.width}
              height={this.props.height}
              paddingHorizontal={this.props.paddingHorizontal}
              debounce={this.props.debounce}
            >
              { label }
            </Toggle>
          </View>
        );
      }
    });
  };

  render() {
    return (
      <View style={{ marginTop: this.props.marginTop, flexDirection: 'row', flexWrap: 'wrap' }}>
        { this.renderToggles() }
      </View>
    );
  }
}
