import React, { Component } from 'react';
import { TouchableNativeFeedback, TouchableOpacity, Platform, View, TouchableWithoutFeedback } from 'react-native';
import PropTypes from 'prop-types';

export default class Button extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]),
    onPress: PropTypes.func,
    isDisabled: PropTypes.bool,
    debounce: PropTypes.number,
    name: PropTypes.string,
    isWithoutFeedback: PropTypes.bool
  };

  static defaultProps = {
    children: <View />,
    onPress: () => {},
    isDisabled: false,
    debounce: 1000,
    name: '',
    isWithoutFeedback: false
  };

  isTouchablePressed = false;

  onPressTouchable = () => {
    if (this.isTouchablePressed) {
      return;
    }

    this.isTouchablePressed = true;

    setTimeout(() => {
      this.isTouchablePressed = false;
    }, this.props.debounce);

    this.props.onPress(this.props.name);
  };

  render() {
    if (this.props.isWithoutFeedback) {
      return (
        <TouchableWithoutFeedback onPress={this.onPressTouchable} disabled={this.props.isDisabled}>
          { this.props.children }
        </TouchableWithoutFeedback>
      );
    }
    else {
      if (Platform.OS == 'android') {
        return (
          <TouchableNativeFeedback onPress={this.onPressTouchable} disabled={this.props.isDisabled}>
            { this.props.children }
          </TouchableNativeFeedback>
        );
      }
      else if (Platform.OS == 'ios') {
        return (
          <TouchableOpacity onPress={this.onPressTouchable} disabled={this.props.isDisabled}>
            { this.props.children }
          </TouchableOpacity>
        );
      }
    }
  }
}
